function plotEllipse(center, a, b, angle, color, style)

% plotEllipse - draw an ellipse into the current figure
%
%   plotEllipse(center, a, b, angle, color, style)
%   
%     draws an ellipse into the current figure where
%
%       center is a two-dimensional vector specifying
%         the ellipse's center
%
%       a and b are the lengths of the semi-axes
%
%       angle is the (clockwise) rotation angle degree
%         from 0 to 360
%
%       color and style are display options using
%         MATLAB conventions

    if nargin < 4, angle= 0; end
    if nargin < 5, color= 'r'; end
    if nargin < 6, style= '-'; end
    if norm(a) < norm(b), c= a; a= b; b= c; end
    if length(a) == 2
        a= a - center;
        b= b - center;
        angle= -atan(a(2)/a(1)) / pi * 180;
        a= norm(a);
        b= norm(b);
    end
    oldAspect= pbaspect;
    pbaspect([1 1 1]);
    
    resolution= a / 20;
    x= -a : resolution : a;
	y= b/a*sqrt(a^2-x.^2);
    y_= -y;
    x_= zeros(size(x));
    
    rm= rotMat(angle);
    for i= 1 : length(x)
        v= rm * [x(i); y(i)];
        v_= rm * [x(i); y_(i)];
        x(i)= v(1);
        y(i)= v(2);
        x_(i)= v_(1);
        y_(i)= v_(2);
    end
    
    x= x + center(1);
    x_= x_ + center(1);
    y= y + center(2);
    y_= y_ + center(2);
    h= ishold;
    hold on;
    if ischar(color)
	    plot(x, y, [style color]);
	    plot(x_, y_, [style color]);
    else
        plot(x, y, style, 'Color', color);
	    plot(x_, y_, style, 'Color', color);
    end
    if h ~= 1, hold off; end
    pbaspect(oldAspect);
    